@@ -1,6 +1,6 @@
-from orionis.metadata.framework import VERSION
 from orionis.console.base.command import BaseCommand
-from orionis.console.exceptions.cli_runtime_error import CLIOrionisRuntimeError
+from orionis.console.exceptions import CLIOrionisRuntimeError
+from orionis.metadata.framework import VERSION
 
 class VersionCommand(BaseCommand):
     """
