@@ -1,7 +1,6 @@
 import json
 import os
 from pathlib import Path
-from orionis.services.environment.env import Env
 from orionis.test.contracts.render import ITestingResultRender
 from orionis.test.records.logs import TestLogs
 
@@ -10,56 +9,44 @@ class TestingResultRender(ITestingResultRender):
     def __init__(
         self,
         result,
-        storage_path:str = None,
-        persist=False
+        storage_path: str,
+        persist: bool = False
     ) -> None:
         """
-        Initialize the TestingResultRender object.
+        Initialize a TestingResultRender instance for rendering test results.
+
+        This constructor sets up the renderer with the provided test result data,
+        determines the storage location for the generated report, and configures
+        whether persistent storage (e.g., SQLite) should be used for storing and
+        retrieving test reports.
 
         Parameters
         ----------
         result : Any
-            The test result data to be processed or stored.
-        storage_path : str, optional
-            Custom path to store the test report. If not provided, uses the environment variable
-            'TEST_REPORT_PATH' or defaults to a local storage path.
+            The test result data to be rendered and included in the report.
+        storage_path : str
+            The directory path where the HTML report will be saved. If the directory
+            does not exist, it will be created automatically.
         persist : bool, optional
-            Whether to persist the report. Defaults to False.
+            If True, enables persistent storage for test reports (default is False).
 
-        Notes
-        -----
-        - Determines the file path for the test report based on the provided storage_path, environment variable,
-          or a default location.
-        - Ensures the parent directory for the report exists.
-        - Stores the resolved report path in the environment variable 'TEST_REPORT_PATH'.
+        Returns
+        -------
+        None
+            This constructor does not return a value. It initializes internal state
+            and prepares the report path for future rendering.
         """
-
-        # Initialize instance variables
-        self.__filename = 'test-results.html'
+        self.__filename = 'orionis-test-results.html'
         self.__result = result
         self.__persist = persist
+        self.__storage_path = storage_path
 
-        # Determine file path
-        db_path = None
-        if storage_path:
-            db_path = Path(storage_path).expanduser().resolve()
-            if db_path.is_dir():
-                db_path = db_path / self.__filename
-        else:
-            env_path = Env.get("TEST_REPORT_PATH", None)
-            if env_path:
-                db_path = Path(env_path).expanduser().resolve()
-                if db_path.is_dir():
-                    db_path = db_path / self.__filename
-            else:
-                db_path = Path.cwd() / 'storage/framework/testing' / self.__filename
+        # Ensure storage_path is a Path object and create the directory if it doesn't exist
+        storage_dir = Path(storage_path)
+        storage_dir.mkdir(parents=True, exist_ok=True)
 
-        # Ensure parent directory exists
-        db_path.parent.mkdir(parents=True, exist_ok=True)
-
-        # Store path in environment
-        Env.set("TEST_REPORT_PATH", str(db_path), 'path')
-        self.__report_path = db_path
+        # Set the absolute path for the report file
+        self.__report_path = (storage_dir / self.__filename).resolve()
 
     def render(
         self
@@ -88,18 +75,26 @@ class TestingResultRender(ITestingResultRender):
 
         # Determine the source of test results based on persistence mode
         if self.__persist:
+
             # If persistence is enabled, fetch the last 10 reports from SQLite
-            logs = TestLogs()
+            logs = TestLogs(self.__storage_path)
             reports = logs.get(last=10)
+
             # Parse each report's JSON data into a list
             results_list = [json.loads(report[1]) for report in reports]
+
         else:
+
             # If not persistent, use only the current in-memory result
             results_list = [self.__result]
 
         # Set placeholder values for the template
-        persistence_mode = 'SQLite' if self.__persist else 'Static'
-        test_results_json = json.dumps(results_list, ensure_ascii=False, indent=None)
+        persistence_mode = 'Database' if self.__persist else 'Memory'
+        test_results_json = json.dumps(
+            results_list,
+            ensure_ascii=False,
+            indent=None
+        )
 
         # Locate the HTML template file
         template_path = Path(__file__).parent / 'report.stub'
@@ -109,23 +104,22 @@ class TestingResultRender(ITestingResultRender):
             template_content = template_file.read()
 
         # Replace placeholders with actual values
-        rendered_content = template_content.replace(
-            '{{orionis-testing-result}}',
-            test_results_json
-        ).replace(
-            '{{orionis-testing-persistent}}',
-            persistence_mode
-        )
+        rendered_content = template_content.replace('{{orionis-testing-result}}', test_results_json)\
+                                           .replace('{{orionis-testing-persistent}}', persistence_mode)
 
         # Write the rendered HTML report to the specified path
         with open(self.__report_path, 'w', encoding='utf-8') as report_file:
             report_file.write(rendered_content)
 
         # Open the generated report in the default web browser if running on Windows or macOS.
-        # This provides immediate feedback to the user after report generation.
-        if os.name == 'nt' or os.name == 'posix' and sys.platform == 'darwin':
-            import webbrowser
-            webbrowser.open(self.__report_path.as_uri())
+        try:
 
-        # Return the absolute path to the generated report
-        return str(self.__report_path)
\ No newline at end of file
+            # Check the operating system and open the report in a web browser if applicable
+            if ((os.name == 'nt') or (os.name == 'posix' and sys.platform == 'darwin')):
+                import webbrowser
+                webbrowser.open(self.__report_path.as_uri())
+
+        finally:
+
+            # Return the absolute path to the generated report
+            return str(self.__report_path)
\ No newline at end of file
